import typer
import os

from pathlib import Path
from typing import Optional
from typing_extensions import Annotated

app = typer.Typer()

@app.command()
def sync(
    config: Annotated[
        typer.FileText, typer.Option()
    ] = "/opt/cstation/etc/github_repo.yaml",
):
    """
        Sync the Github repositories with the upstream repositories
    """
    for line in config:
        if line.strip() != "" or line.startswith('#'):
            print(f"gh repo sync {line.strip()}")
            os.system(f"gh repo sync {line.strip()}")

if __name__ == "__main__":
    app()



import typer
import os
import sys
import ansible_runner

from typing_extensions import Annotated

app = typer.Typer(no_args_is_help=True)

@app.command(no_args_is_help=True)
def ssh_setup(ssh_host: Annotated[str, typer.Argument(help="For Specific Host(s) or All")]):
    print("Setting Up SSH Key to Remote Host...")
    os.chdir('/opt/cstation/ansible_playbook/server/')
    print(f'Setting Up SSH Connection for Host(s): {ssh_host}')
    if ssh_host == "All":
        os.system('ansible-playbook server_ssh.yaml')
    else:
        os.system(f'ansible-playbook -l {ssh_host} server_ssh.yaml')


if __name__ == "__main__":
    app()





import typer


from github import main as github
from docker import main as docker
from server import main as server

app = typer.Typer(no_args_is_help=True, help='Control Station (Internal Use)', rich_markup_mode="markdown")

app.add_typer(server.app, name="server")
app.add_typer(github.app, name="github")
app.add_typer(docker.app, name="docker")


if __name__ == "__main__":
    app()

